@@ -15,12 +15,15 @@ class NotFound(APIError): pass
 class ApplicationError(APIError): pass
 
 class Client:
-    def __init__(self, subdomain_name, api_key, api_secret, oauth_token='', oauth_token_secret='', callback=None, protocol=None, uservoice_domain=None):
+    def __init__(self, subdomain_name, api_key, api_secret=None, oauth_token='', oauth_token_secret='', callback=None, protocol=None, uservoice_domain=None):
         self.request_token = None
         self.token = oauth_token
         self.secret = oauth_token_secret
         self.default_headers = { 'Content-Type': 'application/json', 'Accept': 'application/json',  'API-Client': 'uservoice-python-' + info.version }
-        self.access_token = requests.session(headers=self.default_headers, hooks={'pre_request': OAuthHook(self.token, self.secret, api_key, api_secret, True) })
+        oauth_hooks = {}
+        if api_secret:
+            oauth_hooks = {'pre_request': OAuthHook(self.token, self.secret, api_key, api_secret, True) }
+        self.access_token = requests.session(headers=self.default_headers, hooks=oauth_hooks)
         self.api_url = "{protocol}://{subdomain_name}.{uservoice_domain}".format(
                            subdomain_name=subdomain_name,
                            protocol=(protocol or 'https'),
@@ -37,7 +40,7 @@ class Client:
         url = self.api_url + '/oauth/request_token'
         body = {}
         if self.callback or callback:
-            body['oauth_callback'] = self.callback or callback
+            body['oauth_callback'] = callback or self.callback
         resp = requests.post(url, body, headers=self.default_headers, hooks={'pre_request': OAuthHook('', '', self.api_key, self.api_secret, True)})
         token = parse_qs(resp.text)
         if not 'oauth_token' in token or not 'oauth_token_secret' in token:
@@ -67,6 +70,11 @@ class Client:
         method = method.upper()
 
         url = self.api_url + path
+        if self.api_secret == None:
+            if '?' in url:
+                url += '&client=' + self.api_key
+            else:
+                url += '?client=' + self.api_key
         json_resp = None
         if method == 'POST':
             json_resp = self.access_token.post(url, json.dumps(params))
